@@ -21,8 +21,9 @@ class get_player:
 		if name == None and uuid == None:
 			raise NoInputError
 
-		if not name == None:
-			uuid = get_uuid(name)
+		elif not name == None or not uuid = None:
+			if uuid == None:
+				uuid = get_uuid(name)
 		response = requests.get(f"{HYPIXEL_API}/player?key={self.api}&uuid={uuid}")
 		json = response.json()
 
